@@ -156,7 +156,7 @@ hpgps_start(
 	register struct hpgpsunit *up;
 	struct refclockproc *pp;
 	int fd;
-	int ldisc;
+	int speed, ldisc;
 	char device[20];
 
 	/*
@@ -165,20 +165,22 @@ hpgps_start(
 	 */
 	snprintf(device, sizeof(device), DEVICE, unit);
 	ldisc = LDISC_CLK;
+	speed = SPEED232;
 	/* mode parameter to server config line shares ttl slot */
-	if (1 == peer->ttl)
+	if (1 == peer->ttl) {
 		ldisc |= LDISC_7O1;
-	fd = refclock_open(device, SPEED232Z, ldisc);
+		speed = SPEED232Z;
+	}
+	fd = refclock_open(device, speed, ldisc);
 	if (fd <= 0)
 		return (0);
 	/*
 	 * Allocate and initialize unit structure
 	 */
-	up = emalloc(sizeof(*up));
-	memset(up, 0, sizeof(*up));
+	up = emalloc_zero(sizeof(*up));
 	pp = peer->procptr;
 	pp->io.clock_recv = hpgps_receive;
-	pp->io.srcclock = (caddr_t)peer;
+	pp->io.srcclock = peer;
 	pp->io.datalen = 0;
 	pp->io.fd = fd;
 	if (!io_addclock(&pp->io)) {
@@ -187,7 +189,7 @@ hpgps_start(
 		free(up);
 		return (0);
 	}
-	pp->unitptr = (caddr_t)up;
+	pp->unitptr = up;
 
 	/*
 	 * Initialize miscellaneous variables
@@ -227,7 +229,7 @@ hpgps_shutdown(
 	struct refclockproc *pp;
 
 	pp = peer->procptr;
-	up = (struct hpgpsunit *)pp->unitptr;
+	up = pp->unitptr;
 	if (-1 != pp->io.fd)
 		io_closeclock(&pp->io);
 	if (NULL != up)
@@ -264,9 +266,9 @@ hpgps_receive(
 	/*
 	 * Initialize pointers and read the receiver response
 	 */
-	peer = (struct peer *)rbufp->recv_srcclock;
+	peer = rbufp->recv_peer;
 	pp = peer->procptr;
-	up = (struct hpgpsunit *)pp->unitptr;
+	up = pp->unitptr;
 	*pp->a_lastcode = '\0';
 	pp->lencode = refclock_gtlin(rbufp, pp->a_lastcode, BMAX, &trtmp);
 
@@ -332,7 +334,7 @@ hpgps_receive(
 	 *
 	 */
 
-	strncpy(prompt, pp->a_lastcode, sizeof(prompt));
+	strlcpy(prompt, pp->a_lastcode, sizeof(prompt));
 	tcp = strrchr(pp->a_lastcode,'>');
 	if (tcp == NULL)
 	    tcp = pp->a_lastcode; 
@@ -607,7 +609,7 @@ hpgps_poll(
 	 * declare a timeout and keep going.
 	 */
 	pp = peer->procptr;
-	up = (struct hpgpsunit *)pp->unitptr;
+	up = pp->unitptr;
 	if (up->pollcnt == 0)
 	    refclock_report(peer, CEVNT_TIMEOUT);
 	else
